@@ -24,9 +24,9 @@ $startperl
 # via the filter. Mine looks like this:
 #   "|exec /users/ram/mail/filter >>/users/ram/.bak 2>&1"
 
-# $Id: magent.sh,v 3.0.1.17 2001/03/17 18:07:49 ram Exp $
+# $Id: magent.sh,v 3.0.1.17 2001/03/17 18:07:49 ram Exp ram $
 #
-#  Copyright (c) 1990-1993, Raphael Manfredi
+#  Copyright (c) 1990-2006, Raphael Manfredi
 #  
 #  You may redistribute only under the terms of the Artistic License,
 #  as specified in the README file that comes with the distribution.
@@ -129,6 +129,7 @@ $startperl
 # Current version number and patchlevel
 \$mversion = '$VERSION';
 \$patchlevel = '$PATCHLEVEL';
+\$revision = '$REVISION';
 
 # Want to lock mailboxes with flock ?
 \$lock_by_flock = '$lock_by_flock';
@@ -238,9 +239,12 @@ while ($ARGV[0] =~ /^-/) {
 		$log_level = int(shift);
 	}
 	elsif ($_ eq '-V') {	# Version number
-		print STDERR "$prog_name $mversion PL$patchlevel\n";
+		print STDERR "$prog_name $mversion-$revision\n";
 		exit 0;
 	}
+	elsif ($_ eq '-U') {	# Do not allow UNIQUE to reject / abort
+		++$disable_unique;
+	}
 	elsif ($_ eq '-TEST') {	# Mailagent run via TEST (undocumented feature)
 		++$test_mode;
 	}
@@ -367,6 +371,8 @@ if ($mbox_mail) {
 # message will be skipped anyway, so it's not that critical.
 #
 
+my $process_queue = 1;
+
 if (!$run_queue) {				# Do not enter here if -q
 	if (0 != &pmail($file_name, 0)) {
 		&add_log("ERROR while processing main message--queing it") if $loglvl;
@@ -374,26 +380,32 @@ if (!$run_queue) {				# Do not enter here if -q
 		unlink $lockfile;
 		exit 0;					# Do not continue
 	} 
+
+	# If invoked from a tty and not in test mode, do not process queue
+	$process_queue = 0 if -t STDOUT && !$test_mode; 
 }
 
-unless ($test_mode) {
-	# Fork a child: we have to take care of the filter script which is waiting
-	# for us to finish processing of the delivered mail.
-	&fork_child() unless $run_queue;
+if ($process_queue) {
+	unless ($test_mode) {
+		# Fork a child: we have to take care of the filter script which is
+		# waiting for us to finish processing of the delivered mail.
+		&fork_child() unless $run_queue;
 
-	# From now on, we are in the child process... Don't sleep at all if logging
-	# level is greater that 11 or if $run_queue is true. Logging level of 12
-	# and higher are for debugging and should not be used on a permanent basis
-	# anyway.
+		# From now on, we are in the child process...
+		# Don't sleep at all if logging level is greater that 11
+		# or if $run_queue is true. Logging level of 12 and higher are
+		# for debugging and should not be used on a permanent basis
+		# anyway.
 
-	$sleep = 1;					# Give others a chance to queue their mail
-	$sleep = 0 if $loglvl > 11 || $run_queue;
+		$sleep = 1;					# Give others a chance to queue their mail
+		$sleep = 0 if $loglvl > 11 || $run_queue;
 
-	do {						# Eventually process the queue
-		sleep 30 if $sleep;		# Wait in case new mail arrives
-	} while (&pqueue);
-} else {
-	&pqueue;					# Process the queue once in test mode
+		do {						# Eventually process the queue
+			sleep 30 if $sleep;		# Wait in case new mail arrives
+		} while (&pqueue);
+	} else {
+		&pqueue;					# Process the queue once in test mode
+	}
 }
 
 # Mailagent is exiting. Remove lock file as early as possible to avoid a
@@ -411,7 +423,7 @@ exit 0;
 # Print usage and exit
 sub usage {
 	print STDERR <<EOF;
-Usage: $prog_name [-dhilqtFIV] [-s{umaryt}] [-f file] [-e rules] [-c config]
+Usage: $prog_name [-dhilqtFIVU] [-s{umaryt}] [-f file] [-e rules] [-c config]
        [-L level] [-r file] [-o def] [mailfile]
   -c : specify alternate configuration file.
   -d : dump filter rules (special).
@@ -429,6 +441,7 @@ Usage: $prog_name [-dhilqtFIV] [-s{umaryt}] [-f file] [-e rules] [-c config]
   -I : install configuration and perform sanity checks.
   -L : force logging level.
   -V : print version number and exits.
+  -U : prevent UNIQUE from rejecting an already processed Message-ID.
 EOF
 	exit 1;
 }
@@ -494,9 +507,9 @@ sub init_constants {
 	# The filter message
 	local($address) = &email_addr;
 	$FILTER =
-		"X-Filter: mailagent [version $mversion PL$patchlevel] for $address";
+		"X-Filter: mailagent [version $mversion-$revision] for $address";
 	$MAILER =
-		"X-Mailer: mailagent [version $mversion PL$patchlevel]";
+		"X-Mailer: mailagent [version $mversion-$revision]";
 
 	# For header fields alteration
 	$HD_STRIP = 0;				# Strip header fields
@@ -686,10 +699,10 @@ sub mailbox_name {
 	# override value computed by Configure.
 	$maildir = $cf'maildrop if $cf'maildrop ne '';
 	# If Configure gave a valid 'maildir', use it. Otherwise compute one now.
-	unless ($maildir ne '' && -d "$maildir") {
+	unless ($maildir ne '' && -d $maildir) {
 		$maildir = "/usr/spool/mail";		# Default spooling area
-		-d "/usr/mail" && ($maildir = "/usr/mail");
-		-d "$maildir" || ($maildir = "$cf'home");
+		-d $maildir || (-d "/usr/mail" && ($maildir = "/usr/mail"));
+		-d $maildir || ($maildir = $cf'home);
 	}
 	local($mbox) = $cf'user;					# Default mailbox file name
 	$mbox = $cf'mailbox if $cf'mailbox ne '';	# Priority to config variable
