@@ -1,6 +1,6 @@
-;# $Id: actions.pl,v 3.0.1.21 2001/03/17 18:10:47 ram Exp $
+;# $Id: actions.pl 13 2008-05-28 19:08:54Z rmanfredi $
 ;#
-;#  Copyright (c) 1990-1993, Raphael Manfredi
+;#  Copyright (c) 1990-2006, Raphael Manfredi
 ;#  
 ;#  You may redistribute only under the terms of the Artistic License,
 ;#  as specified in the README file that comes with the distribution.
@@ -763,7 +763,7 @@ sub post {
 		my $when = &header'parsedate($str);
 		my $now = time;
 		my $date;
-		my $AGEMAX = 14 * 86400;		# 14 days
+		my $AGEMAX = 10 * 86400;		# 10 days
 		my $THRESH = 86400;				# 1 day
 		my $WARN_THRESH = 600;			# 10 minutes
 		if ($when < 0) {
@@ -830,11 +830,12 @@ sub post {
 	# Protect Sender: lines in the original message and clean-up header
 	local($last_was_header);		# Set to true when header is skipped
 
-	# Need at most one MIME header, lest article might be rejected
-	my %mime = map { lc($_) => 0 } qw(
+	# Need at most one of the following headers, lest article might be rejected
+	my %single = map { lc($_) => 0 } qw(
 		Mime-Version
 		Content-Transfer-Encoding
 		Content-Type
+		Reply-To
 	);
 
 	foreach (split(/\n/, $Header{'Head'})) {
@@ -862,23 +863,27 @@ sub post {
 			/^Return-Receipt-To:/i	||		# Sendmail's acknowledgment
 			/^Received:/i			||		# We want to remove received
 			/^Precedence:/i			||
+			/^X-Complaints-To:/i	||		# INN2 does not like this field
 			/^Errors-To:/i					# Error report redirection
 		) {
 			$last_was_header = 1;			# Mark we discarded the line
 			next;							# Line is skipped
 		}
-		if (/^([\w-]+):/ && exists $mime{"\L$1"}) {
+		if (/^([\w-]+):/ && exists $single{"\L$1"}) {
 			my $field = lc($1);
-			if ($mime{$field}++) {
+			if ($single{$field}++) {
 				my $nfield = &header'normalize($field);
 				&add_log("WARNING stripping dup $nfield header")
-					if $loglvl > 5 && $mime{$field} == 2;
+					if $loglvl > 5 && $single{$field} == 2;
 				$last_was_header = 1;		# Mark we discarded the line
 				next;						# Line is skipped
 			}
 		}
 		next if /^\s/ && $last_was_header;	# Skip removed header continuations
 		$last_was_header = 0;				# We decided to keep header line
+		# Ensure that we always put a single space after the field name
+		# (before possibly emitting a newline for the continuation)
+		s/^([\w-]+):(\S)/$1: $2/ || s/^([\w-]+):$/$1: /;
 		print NEWS $_, "\n";
 	}
 
@@ -1627,6 +1632,9 @@ sub perl {
 		&add_log("WARNING cannot chdir to $cf'home: $!") if $loglvl > 5;
 	}
 
+	$script =~ s/^\s*~/$cf'home/;	# ~ substitution
+	$script =~ s/\b~/$cf'home/g;	# ~ substitution as first letter in word
+
 	# Set up the @ARGV array, by parsing the $script variable with &shellwords.
 	# Note that the @ARGV array is held in the main package, but since the
 	# mailagent makes no use of it at this point, there is no need to save its
