@@ -1,6 +1,6 @@
-;# $Id: parse.pl,v 3.0.1.16 2001/03/17 18:13:15 ram Exp $
+;# $Id: parse.pl 24 2008-05-30 09:43:23Z rmanfredi $
 ;#
-;#  Copyright (c) 1990-1993, Raphael Manfredi
+;#  Copyright (c) 1990-2006, Raphael Manfredi
 ;#  
 ;#  You may redistribute only under the terms of the Artistic License,
 ;#  as specified in the README file that comes with the distribution.
@@ -142,7 +142,7 @@ sub parse_mail {
 				$Header{$last_header} .= $val if $last_header ne '';
 				&add_log("WARNING bad continuation in header, line $.")
 					if $last_header eq '' && $loglvl > 4;
-			} elsif (($field, $value) = /^([\w-]+)\s*:\s*(.*)/) {
+			} elsif (($field, $value) = /^([!-9;-~\w-]+):\s*(.*)/) {
 				# We found a new header field (i.e. it is not a continuation).
 				# Guarantee only one From: header line. If multiple From: are
 				# found, keep the last one.
@@ -232,12 +232,10 @@ sub header_check {
 	# There is usually one Apparently-To line per address. Remove all new lines
 	# in the header line and replace them with ','. Likewise for To: and Cc:.
 	# although it is far less likely to occur.
-	local($*) = 1;
 	foreach $field ('Apparently-To', 'To', 'Cc') {
-		$Header{$field} =~ s/\n/,/g;	# Remove new-lines
-		$Header{$field} =~ s/,$/\n/;	# Restore last new-line
+		$Header{$field} =~ s/\n/,/gm;	# Remove new-lines
+		$Header{$field} =~ s/,$/\n/m;	# Restore last new-line
 	}
-	$* = 0;
 
 	# If no To: field, then maybe there is an Apparently-To: instead. If so,
 	# make them identical. Otherwise, assume the mail was directed to the user.
@@ -330,6 +328,37 @@ sub relay_list {
 	local($i);
 	local($_);
 
+	# All the known top-level domains as of 2006-08-15
+	# with the addition of "loc" and "private".
+	# See http://data.iana.org/TLD/tlds-alpha-by-domain.txt
+	my $tlds_re = qr/
+		a(?:ero|rpa|[c-gil-oq-uwxz])|
+		b(?:iz|[abd-jmnorstvwyz])|
+		c(?:at|o(?:m|op)|[acdf-ik-oruvxyz])|
+		d[ejkmoz]|
+		e(?:du|[cegr-u])|
+		f[ijkmor]|
+		g(?:ov|[abd-ilmnp-uwy])|
+		h[kmnrtu]|
+		i(?:n(?:fo|t)|[del-oq-t])|
+		j(?:obs|[emop])|
+		k[eghimnrwyz]|
+		l(?:[abcikr-vy]|oc)|
+		m(?:il|obi|useum|[acdghk-z])|
+		n(?:ame|et|[acefgilopruz])|
+		o(?:m|rg)|
+		p(?:r(?:ivate|o)|[ae-hk-nrstwy])|
+		qa|
+		r[eouw]|
+		s[a-eg-ortuvyz]|
+		t(?:ravel|[cdfghj-prtvwz])|
+		u[agkmsyz]|
+		v[aceginu]|
+		w[fs]|
+		y[etu]|
+		z[amw]
+	/ix;
+
 	for ($i = 0; $i < @received; $i++) {
 		$received = $_ = $received[$i];
 
@@ -341,7 +370,7 @@ sub relay_list {
 			) {
 				$host = $1;
 				$host .= ".$cf::domain"
-					if $host =~ /^\w/ && $host !~ /\.\w{2,4}$/;
+					if $host =~ /^\w/ && $host !~ /\.$tlds_re$/;
 				push(@hosts, $host);
 			} else {
 				&add_log("WARNING no by in first Received: line '$received'")
@@ -413,7 +442,7 @@ sub relay_list {
 		# if the "real" host name we attempted to guess is an IP address
 		# or looks like a fully qualified domain name.
 
-		$host = $real if $real =~ /\.\w{2,4}$/ || $real =~ /^\[[\d.]+\]$/;
+		$host = $real if $real =~ /\.$tlds_re$/ || $real =~ /^\[[\d.]+\]$/;
 
 		if ($host eq '') {
 			&add_log("NOTICE no relaying origin in Received: line '$received'")
@@ -453,7 +482,7 @@ sub relay_list {
 
 		unless (
 			$host =~ /^\[[\d.]+\]$/							||
-			$host =~ /^[\w-.]+\.\w{2,4}$/					||
+			$host =~ /^[\w-.]+\.$tlds_re$/					||
 			$host =~ /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/
 		) {
 			next if $host =~ /^[\w-]+$/;	# No message for unqualified hosts
